@@ -3,7 +3,8 @@ context("cutree functions")
 
 mini_corpus <- head(data_corpus_inaugural, n = 2)
 mini_corpus <- split_segments(mini_corpus)
-dtm <- dfm(mini_corpus, remove = stopwords("en"), tolower = TRUE, remove_punct = TRUE)
+dtm <- dfm(tokens(mini_corpus, remove_punct = TRUE), tolower = TRUE)
+dtm <- dfm_remove(dtm, stopwords("en"))
 dtm <- dfm_wordstem(dtm, language = "english")
 dtm <- dfm_trim(dtm, min_termfreq = 3)
 res <- rainette(dtm, k = 3, min_uc_size = 10)
@@ -17,8 +18,8 @@ test_that("generic cutree still works", {
 
 test_that("cutree_rainette is ok", {
   expect_error(cutree(res, h = 200))
-  expect_equal(cutree(res, k = 3), c(3L, 3L, 3L, 3L, 3L, 3L, 3L, 2L, 2L, 2L, 2L, 3L, 3L, 2L, 2L, 
-    2L, 2L, 2L, 1L, 1L, 1L, 2L, 2L, 2L, 2L, 2L, 2L, 1L, 1L, 2L, 2L, 
+  expect_equal(cutree(res, k = 3), c(3L, 3L, 3L, 3L, 3L, 3L, 3L, 2L, 2L, 2L, 2L, 3L, 3L, 2L, 2L,
+    2L, 2L, 2L, 1L, 1L, 1L, 2L, 2L, 2L, 2L, 2L, 2L, 1L, 1L, 2L, 2L,
     2L, 2L, 2L, 2L, 2L, 2L, 3L, 3L, 1L, 1L))
 })
 
